#
# spec file for package apache2-mod_asn
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


BuildRequires:  apache2-devel
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-prefork
BuildRequires:  apache2-worker
#
Name:           apache2-mod_asn
Version:        1.6
Release:        8.5
Summary:        mod_asn Looks up the AS and Network Prefix of IP Address
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
Url:            http://mirrorbrain.org/mod_asn/
#
#
# http://svn.mirrorbrain.org/svn/mod_asn/trunk
Source:         mod_asn-%{version}.tar.gz
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#
%if %{defined suse_version}
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       apache2 >= 2.2.6
Requires:       libapr-util1 >= 1.3.0
Requires:       libapr-util1-dbd-pgsql
%else
Requires:       httpd
%endif

%description

mod_asn is an Apache module doing lookups of the autonomous system (AS)[1], and
the network prefix[2] which contains a given (clients) IP address.

It is written with scalability in mind. To do high-speed lookups, it uses the
PostgreSQL ip4r datatype[3] that is indexable with a Patricia Trie[4] algorithm to
store network prefixes. This is the only algorithm that can search through the
~250.000 existing prefixes in a breeze.

It comes with script to create such a database (and keep it up to date) with
snapshots from global routing data - from a router's "view of the
world", so to speak.

Apache-internally, the module sets the looked up data as env table variables,
for perusal by other Apache modules. In addition, it can send it as response
headers to the client.

It is published under the Apache License, Version 2.0.

Source code can be obtained from http://mirrorbrain.org/mod_asn/ resp.
http://svn.mirrorbrain.org/svn/mod_asn/

Links:
[1] http://en.wikipedia.org/wiki/Autonomous_system_(Internet)
[2] http://en.wikipedia.org/wiki/Subnetwork
[3] http://pgfoundry.org/projects/ip4r/
[4] http://en.wikipedia.org/wiki/Radix_tree

%prep
%setup -q -n mod_asn-%{version}

%build
%{apache_apxs} -c mod_asn.c

%install
mkdir -p %{buildroot}%{apache_libexecdir}
cp -p .libs/mod_asn.so %{buildroot}%{apache_libexecdir}

install -D -m 0755 asn_import.py %{buildroot}%{_bindir}/asn_import
install -D -m 0755 asn_get_routeviews.py %{buildroot}%{_bindir}/asn_get_routeviews

%check
set +x
%apache_test_module_load -m asn:dbd -i mod_asn.conf
set -x

%files
%defattr(-,root,root)
%doc docs
%doc asn.sql
%doc mod_asn.conf
%{apache_libexecdir}/*.so
%{_bindir}/*

%changelog
* Fri Aug 28 2015 pgajdos@suse.com
- test module with %%apache_test_module
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Mon Jun  8 2015 poeml@cmdline.net
- fix dependency on apache2-dev for Debian 7.0/8.0
* Thu Oct 30 2014 pgajdos@suse.com
- call spec-cleaner
- use rpm macros
* Tue Jan  7 2014 poeml@cmdline.net
- update to 1.6 (r100):
  * adjust for the API changes in Apache 2.4 (issue #127, #128)
  * A bug in the asn_get_routeviews script has been fixed: It
    could fail when the BGP routing data snapshot contains bogus AS numbers.
    (issue #93)
  * asn_get_routeviews now allows to only download routing data, but
    don't process it, by using the switch --download-only. In addition,
  - -no-download can be used if the data is distributed by other means, e.g.
    with distro updates. (issue #127)
* Sun Mar  6 2011 draht@suse.de
- checking on shell job control errors upon non-expansion of
  specfile macros.
* Fri Nov 12 2010 poeml@cmdline.net
- enable building on Fedora
* Sun Sep  5 2010 poeml@cmdline.net
- update to 1.5 (r88):
  * mod_asn now avoids lookups of IPv6 addresses. The database of AS
    (autonomous system) numbers is IPv4-only, and in addition, attempted
    lookups seem to cause problems within the PostgreSQL ip4r contrib data
    type.  The symptom was a failure of the database after a while of running,
    and subsequent error messages from Apache. See issue #58.
  * The used version of the APR/APR-Util library is now checked when Apache
    starts, and not when the module is compiled. This is useful to choose the
    correct way to access the database, which unfortunately changed between the
    1.2 and 1.3 (APR-Util) release. This change makes the deployment more
    robust, because even if a user mixes packages from different distro
    versions on a system, mod_asn will still work correctly. This improves the
    existing fix for issue #7.
  * The documentation has been updated with updated examples of Debian package
    names and filenames and an improved example about installing onto an
    existing database.
* Fri Mar 26 2010 poeml@cmdline.net
- update to 1.4 (r78):
  This release does not bring about significant user-visible changes, but under
  the hood, some optimizations were done.
  * For more efficient database connection usage, mod_asn now closes the used
    connection when its handler quits. Before, a connection with lifetime of the
    request was acquired; if a long-running handler runs after mod_asn, this
    could mean that the connection is blocked for other threads until the end of
    the request. This could occur, for instance, when mod_mirrorbrain ran later,
    but exited early because a file was supposed to be delivered directly.
    This was tracked in http://mirrorbrain.org/issues/issue44
  * Database errors from the lower DBD layer are now resolved to strings, where
    available. In relation to this: if an IP address is not found it isn't
    necessarily an error, because it could be a private IP, for instance, which
    is never present in global routing tables. That case is now logged with
    NOTICE log level.
  * When compiling mod_asn with the Apache Portable Runtime 1.2, different
    semantics are used to access database rows, couting from 0 instead of from 1. It
    seemed to work either way (maybe because only a single row is accessed), but
    hopefully now it is done more correctly and therefore safer in the future.
    See http://mirrorbrain.org/issues/issue29 and
    http://mirrorbrain.org/issues/issue7 for the context.
  * In the documentation, the support scripts are now mentioned without their
    :file:`.py` suffix in the example for data import, which might be less
    confusing.
* Thu Jul 30 2009 poeml@suse.de
- update to 1.3 (r69):
  Bugs in the asn_get_routeviews and asn_import scripts were fixed:
  - The logic which decided whether to download the routing data
    snapshot file was fixed. If asn_get_routeviews is called and it
    finds a file which was downloaded less then 8 hours ago, the
    file is reused. If no file exists or the file is older than 8
    hours, it is downloaded again.
  - Deletion of existing entries in the database is now prevented,
    if not at least one entry has been imported. This fixes a bug
    where the routing data would be deleted if the script was
    called with no input.
* Tue Jul 28 2009 poeml@suse.de
- update to release 1.2 (r61):
  * asn_get_routeviews script:
    download data from the mirror provided by the MirrorBrain
    project, so routeviews.org doesn't get additional traffic by
    additional users downloading from them
  * documentation significantly updated
    + section Keep the data up to date added
    + add Upgrading notes about PostgreSQL (8.4)
* Mon Jul 13 2009 poeml@suse.de
- link to svn repo in spec file updated
* Wed Jul  8 2009 poeml@suse.de
- add libapr-util1-dbd-pgsql to Requires
* Sat Jul  4 2009 poeml@suse.de
- update to release 1.1. Changes over r31 were:
  * mod_asn:
  - bump version (1.1)
  - update year in copyright header
  * INSTALL:
  - add instructions for troubleshooting and testing.
  - add links to binaries for Debian and ebuilds for Gentoo
  * CHANGES file added
  * build Debian deb package
* Fri Jun 26 2009 poeml@suse.de
- update to r31:
  - INSTALL: add some rough hints about troubleshooting and testing,
    and correct a wrong example of loading mod_asn instead of mod_dbd
* Mon Jun 22 2009 poeml@suse.de
- update to r30:
  - asn_import script: fix the new -b option introduced with r26
  - add example cron snippet to update ASN data
* Mon Jun 22 2009 poeml@suse.de
- update to r28:
  - implement configuration handling for the asn_import script.
    Thus, it is no longer needed to edit the script with database
    configuration data and credentials. Two ways of configuration
    are supported:
  * if a MirrorBrain config file is found, it is used (and the
    MirrorBrain instance can be selected with -b on the
    commandline, if needed)
  * alternatively, the script looks for a config file named
    /etc/asn_import.conf.
  - updated asn_import script which handles the slightly changed
    format of the snapshots of routeviews data. Additionally, more
    sanity checks for invalid lines were required.
* Thu Jun  4 2009 poeml@suse.de
- add buildrequires to enable building on CentOS 5.
* Tue Mar 31 2009 poeml@suse.de
- update to r22:
  - fix bug that lead to ignorance of variables in the subprocess
    environment set by ASIPEnvvar, which falsely looked for the
    wrong variable name (one that was configured via ASIPHeader).
* Tue Mar 17 2009 poeml@suse.de
- update to r21:
  - document an example how to log the looked up data
* Tue Mar 17 2009 poeml@suse.de
- update to r20:
  - updated README with documentation on design choices and
    performance.
  - INSTALL: add note about required versions of httpd and
    apr-util.
* Tue Mar 17 2009 poeml@suse.de
- update to r16:
  update README:
  - client ip override has been implemented.
  - add some reference to mod_mirrorbrain and its tool set
* Mon Mar 16 2009 poeml@suse.de
- update to r14:
  - implement lookup of IP address taken from an arbitrary HTTP
    request header, or an subprocess environment variable:
    configurable via ASIPHeader and ASIPHeader directives.
  - document the ASLookupDebug directive.
  - bump version to 1.0.
* Mon Mar 16 2009 poeml@suse.de
- update to svn r11; no functional change, mostly documentation
  updates.
* Fri Feb 13 2009 poeml@suse.de
- work on INSTALL and README
* Thu Feb 12 2009 poeml@suse.de
- work on the INSTALL docs
- README added
* Thu Feb 12 2009 poeml@suse.de
- work on the INSTALL docs
- removed accidentally checked in password (yes, it is stupid to
  put passwords in scripts, and yes, I changed it on the server)
- simplify usage of asn_get_routeviews.py
* Thu Feb 12 2009 poeml@suse.de
- initial package (0.9)
